CTdeconv: CTdeconv: An immune cell-type deconvolution method.

Description Usage Arguments Value Examples

View source: R/CTdeconv.R

Description

This function integrates deconvolution results of three agrithom-signature combinations which show best performance in our benchmark datasets and provides the relative proportions of six immune cell types in mixture samples.

Usage

1
CTdeconv(mix, cibersortPath, RNAseq = F, cellFrac = F, filename = NULL)

Arguments

mix

A matrix (n Genes * m Samples) of genes expression from bulk samples . It can be a string which specifies the path of a expression 'tsv' file. The rownames must be gene symbols and the colnames are the sample id.

cibersortPath

Path to cibersort R script. CIBERSORT is freely available to academic users. Cibersort source script can be obtained from https://cibersort.stanford.edu.

RNAseq

Logical. If TURE, the expression data is RNA-Seq data rather than Macroarray data, and the quantile normalization will not be done during Cibersort analysis process. The default is FALSE.

cellFrac

Logical. If FALSE (default), the proportion of mRNA coming from each cell type will be returned. If TRUE, a renormalization process will be performed on the mRNA proportion to account for different mRNA / cell values in different cell types, as is recommended in EPIC. In this way, the proportion of cells from each cell type will be returned

filename

A string indecates the path of the file to be saved. If NULL (default), no file will be saved.

Value

A matrix (m Samples * 6 Celltypes). It provides the proprotions of six cell types in the bulk samples. Note that the proportion is relative since we conduct a normalization to make the sum of proportions in each sample be one.

Examples

1
2
3
# You need to provide path to CIBERSORT.R
path='D:/Users/xiergo/Documents/CIBERSORT.R'
res=CTdeconv(mix,cibersortPath=path)

xiergo/CTdeconv documentation built on Dec. 27, 2019, 2:57 a.m.